
## CATO-CLI - mutation.policy.internetFirewall:
[Click here](https://api.catonetworks.com/documentation/#mutation-internetFirewall) for documentation on this operation.

### Usage for mutation.policy.internetFirewall:

`catocli mutation policy internetFirewall -h`
